Description Usage Arguments Value Author(s) References Examples
Quickly import microbiome data and bulding phyloseq object
1 2 |
otu |
dataframe,otu table |
tax |
data.frame, tax table |
map |
matrix or dataframe, including sampleID and groupID; |
tree |
Evolutionary tree |
ps |
a phyloseq object |
group |
column name for groupID. |
a phyloseq object
Contact: Tao Wen 2018203048@njau.edu.cn Jun Yuan junyuan@njau.edu.cn
Yuan J, Zhao J, Wen T, Zhao M, Li R, Goossens P, Huang Q, Bai Y, Vivanco JM, Kowalchuk GA, Berendsen RL, Shen Q Root exudates drive the soil-borne legacy of aboveground pathogen infection Microbiome 2018,DOI: doi: 10.1186/s40168-018-0537-x
1 2 3 4 |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.