Description Usage Arguments Value Author(s) References Examples
transform a otu table object from phyloseq object to matrix
1 | vegan_otu(physeq)
|
physeq |
a phyloseq object from R package phyloseq |
matrix
Contact: Tao Wen 2018203048@njau.edu.cn Jun Yuan junyuan@njau.edu.cn
Yuan J, Zhao J, Wen T, Zhao M, Li R, Goossens P, Huang Q, Bai Y, Vivanco JM, Kowalchuk GA, Berendsen RL, Shen Q Root exudates drive the soil-borne legacy of aboveground pathogen infection Microbiome 2018,DOI: doi: 10.1186/s40168-018-0537-x
1 | otu = otu_table(ps)
|
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.